
# Github MCP Server

An MCP Server for the Github API.

## Supported Integrations

- AgentR
- API Key (Coming Soon)
- OAuth (Coming Soon)

## Tools

This is automatically generated from OpenAPI schema for the Github API.

## Supported Integrations

This tool can be integrated with any service that supports HTTP requests.

## Tool List

| Tool | Description |
|------|-------------|
| create_issue | Create a new issue in a GitHub repository |
| create_pull_request | Create a new pull request for a GitHub repository |
| get_pull_request | Get a specific pull request for a GitHub repository |
| list_branches | List branches for a GitHub repository |
| list_commits | List recent commits for a GitHub repository |
| list_issues | List issues for a GitHub repository |
| list_pull_requests | List pull requests for a GitHub repository |
| list_repo_activities | List activities for a GitHub repository |
| star_repository | Star a GitHub repository |
| update_issue | Update an issue in a GitHub repository |
| validate | Function for validate |



## Usage

- Login to AgentR
- Follow the quickstart guide to setup MCP Server for your client
- Visit Apps Store and enable the Github app
- Restart the MCP Server

### Local Development

- Follow the README to test with the local MCP Server
